tsseg.algorithms.prophet package
================================

Wraps Facebook Prophet's piecewise-linear trend model to extract change points.

| **Type:** change point detection
| **Supervision:** semi-supervised
| **Requires:** ``prophet`` and ``cmdstanpy``

**Implementation:** Wrapper around facebook/prophet. MIT.

Submodules
----------

tsseg.algorithms.prophet.detector module
----------------------------------------

.. automodule:: tsseg.algorithms.prophet.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.prophet
   :members:
   :show-inheritance:
   :undoc-members:
